@@ -8,7 +8,7 @@ from geolocation import const
 
 class BaseApi(object):
 
-    log = logging.Logger('google_api')
+    log = logging.getLogger('google_api')
 
     def __init__(self, api_key):
         self.api_key = "&key=%s" % api_key
@@ -35,7 +35,7 @@ class BaseApi(object):
 
         self.log.warning(self.get_status_code(status))
 
-    def prepare_query(self, location=None, latlng=None):
+    def prepare_query(self, location=None, lat=None, lng=None):
         """Method prepares query to request for google api. This method have to be implemented on all apis."""
         raise Exception(const.NOT_IMPLEMENTED)
 
